@@ -35,14 +35,14 @@ Returns all documents making up the blog.
 =cut
 
 sub all_documents {
-    my ($self, $config) = @_;
-    croak "Must pass in a Bryar::Config object" unless UNIVERSAL::isa($config, "Bryar::Config");
+    my ($self, $bryar) = @_;
+    croak "Must pass in a Bryar object" unless UNIVERSAL::isa($bryar, "Bryar");
     my $where = cwd;
-    chdir($config->datadir); # Damn you, F::F::R.
+    chdir($bryar->{config}->datadir); # Damn you, F::F::R.
     my @docs = map { $self->make_document($_) }
                 File::Find::Rule->file()
                                 ->name($self->entry_glob)
-                                ->maxdepth($config->depth)
+                                ->maxdepth($bryar->{config}->depth)
                                 ->in(".");
     chdir($where);
     return @docs;
@@ -71,24 +71,24 @@ sub file_to_id { my $file = $_[1]; $file =~ s/.txt$//; $file; }
 
 =head2 search
 
-    $self->search($bryar, $config, %params)
+    $self->search($bryar, %params)
 
 A more advanced search for specific documents
 
 =cut
 
 sub search {
-    my ($self, $config, %params) = @_;
-    croak "Must pass in a Bryar::Config object" unless UNIVERSAL::isa($config, "Bryar::Config");
+    my ($self, $bryar, %params) = @_;
+    croak "Must pass in a Bryar object" unless UNIVERSAL::isa($bryar, "Bryar");
     my $was = cwd;
-    my $where = $config->datadir."/";
+    my $where = $bryar->{config}->datadir."/";
     if ($params{subblog}) { $where .= $params{subblog}; }
     chdir($where); # Damn you, F::F::R.
     
     my $find = File::Find::Rule->file();
     if ($params{id}) { $find->name($self->id_to_file($params{id})) }
                 else { $find->name($self->entry_glob) }
-    $find->maxdepth($config->depth);
+    $find->maxdepth($bryar->{config}->depth);
     if ($params{since})   { $find->mtime(">".$params{since}) }
     if ($params{before})  { $find->mtime("<".$params{before}) }
     my @docs;
@@ -128,11 +128,10 @@ sub make_document {
     local $/;
     my $content = <$in>;
     close $in;
-    my $id = $self->file_to_id($file);
 
     my $comments = [];
-    $comments = [_read_comments($id, $id.".comments") ]
-        if -e $id.".comments";
+    $comments = [_read_comments($file, $file.".comments") ]
+        if -e $file.".comments";
 
     my $dir = dirname($file);
     $dir =~ s{^\./?}{};
@@ -142,7 +141,7 @@ sub make_document {
         content  => $content,
         epoch    => $when,
         author   => $who,
-        id       => $id,
+        id       => $self->file_to_id($file),
         category => $category,
         comments => $comments
     );
@@ -178,11 +177,11 @@ Records the given comment details.
 =cut
 
 sub add_comment {
-    my ($self, $config) = (shift, shift);
+    my ($self, $bryar) = (shift, shift);
     my %params = @_;
     my $file = $params{document}->id.".comments";
     # This probably fails with subblogs, but I don't use them.
-    chdir $config->datadir."/";
+    chdir $bryar->{config}->datadir."/";
     open OUT, ">> $file" or die $!;
     delete $params{document};
     s/\n/\r/g for values %params;
